@@ -21,7 +21,7 @@ from .shortcuts import (
 from .unittest import TestCaseMixin, disable_elastic_apm, disable_migration, disable_network, fake_time, mock_redis_lock
 from .validators import is_chinese_phone, is_int, is_phone, is_singapore_phone, is_uuid
 
-__version__ = "1.0.15"
+__version__ = "1.0.16"
 
 __all__ = [
     "EmptyContextManager",
@@ -64,7 +64,7 @@ __all__ = [
 ]
 
 try:
-    from .django.apis import Errors, check_error, get_object_or_error, get_validation_error  # NOQA
+    from .django.apis import Errors, check_error, get_object_or_error, get_request_ip, get_validation_error  # NOQA
     from .django.databases import DynamicField, ExtendModelMixin, HManager, HQuerySet, ModelMixin  # NOQA
     from .django.migrations import AlterDefault  # NOQA
     from .django.unittest import extend_django_sqlite  # NOQA
@@ -81,6 +81,7 @@ try:
             "check_error",
             "extend_django_sqlite",
             "get_object_or_error",
+            "get_request_ip",
             "get_validation_error",
         ]
     )
